/**
 * @file
 * Plugin definition and settings.
 */

'use strict';

CKEDITOR.plugins.add('ckeditor_layouts', {
  icons: 'layouts',
  init: pluginInit
});

function pluginInit(editor) {
  editor.responsivearea_path = this.path;

  editor.ui.addButton('AddLayout', {
    label: Drupal.t('Insert a layout'),
    command: 'beLayout',
    icon: this.path + 'icons/layouts.png'
  });


  editor.addCommand('beLayout', {
    exec: function (editor, data) {
      editor.openDialog('AddLayoutDialog' + editor.name);
    }
  });

  CKEDITOR.dialog.add('AddLayoutDialog' + editor.name, beLayout);
}

function beLayout(editor, data) {
  const layouts = editor.config.ckeditorLayouts_layouts;
  let default_layout_id = null;
  let items = [];

  layouts.forEach(function (layout, index) {
    if (null === default_layout_id) {
      default_layout_id = layout.id;
    }

    const item = [
      '<br><small>' + layout.label + '</small><br><br>' + layout.image,
      layout.id
    ];
    items.push(item);
  });

  return {
    title: Drupal.t('Insert a layout'),
    minWidth: 400,
    minHeight: 200,
    contents: [
      {
        id: 'tab-basic',
        label: 'Layouts',
        elements: [
          {
            type: 'radio',
            id: 'layout',
            label: '<p><strong>' + Drupal.t('Please choose the layout you want') + ':</strong></p><br />',
            items: items,
            style: 'display: block;',
            default: default_layout_id
          }
        ]
      }
    ],
    onOk: function () {
      const dialog = this;
      const layouts = editor.config.ckeditorLayouts_layouts;
      const selected_layout_id = dialog.getValueOf('tab-basic', 'layout');
      const layout = layouts.find(function (layout, index, layouts) {
        return layout.id === selected_layout_id;
      }, selected_layout_id);
      const tpl = layout.template || "";
      if (tpl !== "") {
        editor.insertHtml(tpl);
      }
    }
  };
}
